PVAccess for Python
===================

Python bindings for the PVAccess network client and server.

    python -m virtualenv p4ptest
    . p4ptest/bin/activate
    python -m pip install -U pip
    python -m pip install p4p
    python -m nose p4p

See documentation

https://mdavidsaver.github.io/p4p/

Source

https://travis-ci.org/mdavidsaver/p4p/

CI results

https://travis-ci.org/mdavidsaver/p4p
https://ci.appveyor.com/project/mdavidsaver/p4p

[![Build Status](https://travis-ci.org/mdavidsaver/p4p.svg?branch=master)](https://travis-ci.org/mdavidsaver/p4p)
[![Build status](https://ci.appveyor.com/api/projects/status/ov2ka6jn52n87vku/branch/master?svg=true)](https://ci.appveyor.com/project/mdavidsaver/p4p/branch/master)
